
'''Okay, so this is the help docuement for this module
blah blah blah
etc etc etc'''


def calculate_at(dna):
    length = len(dna)
    a_count = dna.count('A')
    t_count = dna.count('T')
    at_content = (a_count + t_count) / length
    return at_content



from setuptools import setup

setup(name = 'upload_dnatools_36',
version = '0.1',
description = 'textbook example',
url = 'http://example.com',
author = 'Example',
author_email = 'Example@gmail.com',
license = 'Example',
packages = ['package_1'])
